@@ -5,19 +5,24 @@ from tsuru_unit_agent import tasks
 from tsuru_unit_agent.client import Client
 
 
-def run_action(args):
+def run_action(args, run_hooks=True):
     client = Client(args.url, args.token)
     envs = client.register_unit(args.app_name)
     tasks.save_apprc_file(envs)
-    tasks.execute_start_script(args.start_cmd, envs)
-    return client, envs
+    if run_hooks:
+        yaml_data = tasks.load_app_yaml()
+        tasks.run_restart_hooks('before', yaml_data)
+    tasks.execute_start_script(args.start_cmd)
+    if run_hooks:
+        tasks.run_restart_hooks('after', yaml_data)
+    return client
 
 
 def deploy_action(args):
-    client, envs = run_action(args)
+    client = run_action(args, run_hooks=False)
     yaml_data = tasks.load_app_yaml()
     client.post_app_yaml(args.app_name, yaml_data)
-    tasks.run_hooks(yaml_data, envs)
+    tasks.run_build_hooks(yaml_data)
 
 
 actions = {
